@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "messageparser.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "attachmentmodel.h"
 #include "mimetreeparser_core_debug.h"
@@ -15,7 +16,7 @@ namespace
 {
 
 template<typename T>
-const T *findHeader(KMime::Content *content, KMime::Content *protectedHeaderNode)
+const T *findHeader(const KMime::Content *content, const KMime::Content *protectedHeaderNode)
 {
     if (protectedHeaderNode) {
         auto header = protectedHeaderNode->header<T>();
@@ -36,7 +37,7 @@ QString mailboxesToHtml(const KMime::Types::Mailbox::List &mailboxes)
     QStringList html;
     for (const auto &mailbox : mailboxes) {
         if (mailbox.hasName() && mailbox.hasAddress()) {
-            html << QStringLiteral("%1 <%2>").arg(mailbox.name().toHtmlEscaped(), QString::fromUtf8(mailbox.address()).toHtmlEscaped());
+            html << u"%1 <%2>"_s.arg(mailbox.name().toHtmlEscaped(), QString::fromUtf8(mailbox.address()).toHtmlEscaped());
         } else if (mailbox.hasAddress()) {
             html << QString::fromUtf8(mailbox.address());
         } else {
@@ -110,7 +111,7 @@ void MessageParser::setMessage(const KMime::Message::Ptr message)
                 d->ownedContent = std::make_unique<KMime::Content>();
                 // we put the decoded content as encoded content of the new node
                 // as the header are inline in part->node()
-                d->ownedContent->setContent(part->node()->decodedContent());
+                d->ownedContent->setContent(part->node()->decodedBody());
                 d->ownedContent->parse();
                 d->protectedHeaderNode = d->ownedContent.get();
                 break;
