@@ -26,6 +26,7 @@
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
 #include <gpgme.h>
+using namespace Qt::Literals::StringLiterals;
 
 using namespace MimeTreeParser;
 
@@ -97,13 +98,13 @@ static KMime::Headers::ContentType *contentType(KMime::Content *node)
 QByteArray MessagePart::charset() const
 {
     if (!mNode) {
-        return QByteArrayLiteral("us-ascii");
+        return "us-ascii"_ba;
     }
     if (auto ct = contentType(mNode)) {
         return ct->charset();
     }
     // Per rfc2045 us-ascii is the default
-    return QByteArrayLiteral("us-ascii");
+    return "us-ascii"_ba;
 }
 
 QByteArray MessagePart::mimeType() const
@@ -221,7 +222,7 @@ void MessagePart::parseInternal(const QByteArray &data)
     bindLifetime(tempNode);
 
     if (!tempNode->head().isEmpty()) {
-        tempNode->contentDescription()->from7BitString(QByteArrayLiteral("temporary node"));
+        tempNode->contentDescription()->from7BitString("temporary node"_ba);
     }
 
     parseInternal(tempNode);
@@ -357,7 +358,7 @@ void TextMessagePart::parseContent()
 {
     mSignatureState = KMMsgNotSigned;
     mEncryptionState = KMMsgNotEncrypted;
-    const auto blocks = prepareMessageForDecryption(mNode->decodedContent());
+    const auto blocks = prepareMessageForDecryption(mNode->decodedBody());
     // We also get blocks for unencrypted messages
     if (!blocks.isEmpty()) {
         auto aCodec = QStringDecoder(mOtp->codecNameFor(mNode).constData());
@@ -463,7 +464,7 @@ HtmlMessagePart::HtmlMessagePart(ObjectTreeParser *otp, KMime::Content *node)
         return;
     }
 
-    setText(QStringDecoder(mOtp->codecNameFor(mNode).constData()).decode(KMime::CRLFtoLF(mNode->decodedContent())));
+    setText(QStringDecoder(mOtp->codecNameFor(mNode).constData()).decode(KMime::CRLFtoLF(mNode->decodedBody())));
 }
 
 //-----MimeMessageBlock----------------------
@@ -643,7 +644,7 @@ void SignedMessagePart::startVerification()
 
     // If we have a mNode, this is a detached signature
     if (mNode) {
-        const auto signature = mNode->decodedContent();
+        const auto signature = mNode->decodedBody();
 
         // This is necessary in case the original data contained CRLF's. Otherwise the signature will not match the data (since KMIME normalizes to LF)
         const QByteArray signedData = KMime::LFtoCRLF(mSignedData->encodedContent());
@@ -655,7 +656,7 @@ void SignedMessagePart::startVerification()
     } else {
         QByteArray outdata;
         const auto job = mCryptoProto->verifyOpaqueJob();
-        setVerificationResult(job->exec(mSignedData->decodedContent(), outdata), outdata);
+        setVerificationResult(job->exec(mSignedData->decodedBody(), outdata), outdata);
         job->deleteLater();
         setText(codec.decode(KMime::CRLFtoLF(outdata)));
     }
@@ -758,7 +759,7 @@ bool EncryptedMessagePart::decrypt(KMime::Content &data)
     //  mMetaData.auditLogError = GpgME::Error();
     mMetaData.auditLog.clear();
 
-    const QByteArray ciphertext = data.decodedContent();
+    const QByteArray ciphertext = data.decodedBody();
     QByteArray plainText;
     auto job = mCryptoProto->decryptVerifyJob();
     const std::pair<GpgME::DecryptionResult, GpgME::VerificationResult> p = job->exec(ciphertext, plainText);
